==> 3050-PostSoftwareAssuranceTool-1.2.1-1.zip: RegisterReportDlg.h <==
#if !defined(AFX_REGISTERREPORTDLG_H__740E1C73_C298_412A_9205_1731C9C94CF7__INCLUDED_)
#define AFX_REGISTERREPORTDLG_H__740E1C73_C298_412A_9205_1731C9C94CF7__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// RegisterReportDlg.h : header file
//

/////////////////////////////////////////////////////////////////////////////
// CRegisterReportDlg dialog

class CRegisterReportDlg : public CDialog
{
// Construction
public:
	CRegisterReportDlg(CWnd* pParent = NULL);   // standard constructor
	void DrawBackground ( CDC* pDC );
	void SetWindowPosition ( CRect rtPosition );
	
// Dialog Data
	CBitmap			m_bmBackground;
	CPoint			m_ptPosition;

	//	enum { IDD = IDD_REGISTER_REPORT_DIALOG 254 };

	//{{AFX_DATA(CRegisterReportDlg)
	enum { IDD = 254 };
	CEdit	m_editContent;
	YButton	m_btnRegister;
	YButton	m_btnCancel;
	CString	m_strContent;
	//}}AFX_DATA


// Overrides
	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CRegisterReportDlg)
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
	//}}AFX_VIRTUAL

// Implementation
protected:

	// Generated message map functions
	//{{AFX_MSG(CRegisterReportDlg)
	afx_msg void OnButtonRegister();
	afx_msg void OnButtonCancel();
	afx_msg void OnPaint();
	virtual BOOL OnInitDialog();

	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_REGISTERREPORTDLG_H__740E1C73_C298_412A_9205_1731C9C94CF7__INCLUDED_)

==> 3050-PostSoftwareAssuranceTool-2.0.0-1.zip: RegisterReportDlg.h <==
#if !defined(AFX_REGISTERREPORTDLG_H__740E1C73_C298_412A_9205_1731C9C94CF7__INCLUDED_)
#define AFX_REGISTERREPORTDLG_H__740E1C73_C298_412A_9205_1731C9C94CF7__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// RegisterReportDlg.h : header file
//

/////////////////////////////////////////////////////////////////////////////
// CRegisterReportDlg dialog

class CRegisterReportDlg : public CDialog
{
// Construction
public:
	CRegisterReportDlg(CWnd* pParent = NULL);   // standard constructor
	void DrawBackground ( CDC* pDC );
	void SetWindowPosition ( CRect rtPosition );
	
// Dialog Data
	CRect			m_rtTitleBar;
	char*			m_pCursor;
	CPoint			m_ptWindowMove;
	CPoint			m_ptWindowPosition;
	int				m_nMouseState;

	CBitmap			m_bmBackground;
	CPoint			m_ptPosition;
	BOOL			m_bFirst;
	//	enum { IDD = IDD_REGISTER_REPORT_DIALOG 254 };

	//{{AFX_DATA(CRegisterReportDlg)
	enum { IDD = 254 };
	CEdit	m_editContent;
	YButton	m_btnRegister;
	YButton	m_btnCancel;
	CString	m_strContent;
	//}}AFX_DATA


// Overrides
	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CRegisterReportDlg)
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
	//}}AFX_VIRTUAL

// Implementation
protected:

	// Generated message map functions
	//{{AFX_MSG(CRegisterReportDlg)
	afx_msg void OnButtonRegister();
	afx_msg void OnButtonCancel();
	afx_msg void OnPaint();
	virtual BOOL OnInitDialog();
	afx_msg void OnLButtonDown(UINT nFlags, CPoint point);
	afx_msg void OnLButtonUp(UINT nFlags, CPoint point);
	afx_msg void OnMouseMove(UINT nFlags, CPoint point);
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_REGISTERREPORTDLG_H__740E1C73_C298_412A_9205_1731C9C94CF7__INCLUDED_)
